@@ -29,8 +29,6 @@ class Constants;
 class QButtonGroup;
 class KToggleAction;
 
-#include <kxmlguiwindow.h>
-
 /*
   Kcalc basically consist of a class for the GUI (here), a class for
   the display (dlabel.h), and one for the mathematics core
@@ -62,6 +60,8 @@ class KToggleAction;
 #include "ui_constants.h"
 #include "ui_colors.h"
 
+#include <kxmlguiwindow.h>
+
 class  General: public QWidget, public Ui::General
 {
 public:
@@ -100,33 +100,34 @@ class KCalculator : public KXmlGuiWindow, private Ui::KCalculator
     Q_OBJECT
 
 public:
-	KCalculator(QWidget *parent = 0);
-	~KCalculator();
+    KCalculator(QWidget *parent = 0);
+    ~KCalculator();
 
 signals:
-	void switchInverse(bool);
-	void switchMode(ButtonModeFlags,bool);
-	void switchShowAccels(bool);
+    void switchInverse(bool);
+    void switchMode(ButtonModeFlags,bool);
+    void switchShowAccels(bool);
 
 private:
-	virtual bool eventFilter( QObject *o, QEvent *e );
-	void updateGeometry();
-	void setupMainActions(void);
-	void setupStatusbar(void);
-	void setupKeys();
-	void keyPressEvent(QKeyEvent *e);
-	void keyReleaseEvent(QKeyEvent *e);
-	void set_precision();
-	void set_style();
-	void resetBase(void) { decRadio->animateClick(); }
+    virtual bool eventFilter( QObject *o, QEvent *e );
+    void updateGeometry();
+    void setupMainActions(void);
+    void setupStatusbar(void);
+    void setupKeys();
+    void keyPressEvent(QKeyEvent *e);
+    void keyReleaseEvent(QKeyEvent *e);
+    void setPrecision();
+    void setAngle();
+    void setBase();
 
-	void updateDisplay(bool get_amount_from_core = false,
-			   bool store_result_in_history = false);
+    void updateDisplay(bool get_amount_from_core = false,
+                       bool store_result_in_history = false);
 
 protected slots:
     void changeButtonNames();
     void updateSettings();
-    void set_colors();
+    void setColors();
+    void setFonts();
     void EnterEqual();
     void showSettings();
     void slotStatshow(bool toggled);
@@ -207,10 +208,10 @@ private:
         GradMode
     };
     enum BaseMode {
-        HexMode = 0,
-        DecMode,
-        OctMode,
-        BinMode
+        BinMode = 2,
+        OctMode = 8,
+        DecMode = 10,
+        HexMode = 16
     };
 
 private:
