@@ -26,7 +26,6 @@
 #include "editaction.h"
 #include "prototype.h"
 #include "profileserver.h"
-#include "remoteserver.h"
 #include "addaction.h"
 #include "dbusinterface.h"
 
@@ -36,6 +35,7 @@
 #include <kmessagebox.h>
 #include <knuminput.h>
 #include <keditlistbox.h>
+#include <solid/control/remotecontrol.h>
 #include <QStandardItemModel>
 #include <QHeaderView>
 
@@ -44,10 +44,9 @@ EditAction::EditAction(IRAction *action, const QStringList &modeList, QWidget *p
     theAction = action;
     editActionBaseWidget = new EditActionBaseWidget();
     setMainWidget(editActionBaseWidget);
-    setButtons( Ok | Cancel);
+    setButtons( Ok | Cancel | Try);
     setDefaultButton(Ok);
     setModal(modal);
-    //editActionBaseWidget->theDBusApplications->setModel(new DBusServiceModel(0));
     dbusServiceModel = new QStandardItemModel(editActionBaseWidget->theDBusApplications);
     editActionBaseWidget->theDBusApplications->setModel(dbusServiceModel);
     mainGroup.addButton(editActionBaseWidget->theUseDBus);
@@ -59,17 +58,19 @@ EditAction::EditAction(IRAction *action, const QStringList &modeList, QWidget *p
     foreach(const QString &mode, modeList) {
         editActionBaseWidget->theModes->addItem(mode);
     }
+    buttonModel = new RemoteButtonModel(Solid::Control::RemoteControl(theAction->remote()).buttons(), editActionBaseWidget->theButtons);
+    editActionBaseWidget->theButtons->setModel(buttonModel);
+    
+    editActionBaseWidget->theButtons->setCurrentIndex(buttonModel->indexOfButtonName(theAction->button()).row());
 
     updateApplications();
     connectSignalsAndSlots();
-    //initDBusApplications();
 
     argumentsModel = new QStandardItemModel(editActionBaseWidget->argumentsView);    
     editActionBaseWidget->argumentsView->setModel(argumentsModel);
     editActionBaseWidget->argumentsView->setItemDelegate(new ArgumentDelegate());
     argumentsModel->setHeaderData(0, Qt::Horizontal, i18n("Argument name"));
     argumentsModel->setHeaderData(1, Qt::Horizontal, i18nc("The value of an argument", "Value"));
-
     readFrom();
 
 }
@@ -134,6 +135,8 @@ void EditAction::connectSignalsAndSlots() {
     connect(editActionBaseWidget->theChangeMode,SIGNAL(toggled(bool)),editActionBaseWidget->theDoBefore,SLOT(setEnabled(bool)));
     connect(editActionBaseWidget->theChangeMode,SIGNAL(toggled(bool)),editActionBaseWidget->theModes,SLOT(setEnabled(bool)));
     connect(editActionBaseWidget->theChangeMode,SIGNAL(toggled(bool)),this,SLOT(updateInstancesOptions()));
+
+    connect(this, SIGNAL(tryClicked()), this, SLOT(tryAction()));
 }
 
 void EditAction::readFrom()
@@ -159,10 +162,10 @@ void EditAction::readFrom()
             editActionBaseWidget->theModes->setCurrentIndex(editActionBaseWidget->theModes->findText(theAction->object()));
     } else if (theAction->isJustStart()) { // profile action
         editActionBaseWidget->theUseProfile->setChecked(true);
-        const Profile *p = ProfileServer::profileServer()->getProfileById(theAction->program());
+        const Profile *p = ProfileServer::getInstance()->getProfileById(theAction->program());
         editActionBaseWidget->theApplications->setCurrentIndex(editActionBaseWidget->theApplications->findText(p->name()));
         editActionBaseWidget->theJustStart->setChecked(true);
-    } else if (ProfileServer::profileServer()->getAction(theAction->program(), theAction->object(), theAction->method().prototype())) { // profile action
+    } else if (ProfileServer::getInstance()->getAction(theAction->program(), theAction->object(), theAction->method().prototype())) { // profile action
         editActionBaseWidget->theUseProfile->setChecked(true);
         editActionBaseWidget->thePerformFunction->setChecked(true);
     } else { // DBus action
@@ -172,10 +175,9 @@ void EditAction::readFrom()
 
 IRAction* EditAction::getAction()
 {
-    IRAction* tAction = new IRAction();
-    tAction->setRemote(theAction->remote());
+    RemoteControlButton *tButton = buttonModel->getButton( editActionBaseWidget->theButtons->currentIndex());
+    IRAction* tAction = new IRAction(tButton->remoteName(), tButton->name());
     tAction->setMode(theAction->mode());
-    tAction->setButton(theAction->button());
     if (editActionBaseWidget->theChangeMode->isChecked()) {
         tAction->setProgram("");
         if (editActionBaseWidget->theModes->currentText() == i18n("[Exit current mode]"))
@@ -185,11 +187,10 @@ IRAction* EditAction::getAction()
         tAction->setDoBefore(editActionBaseWidget->theDoBefore->isChecked());
         tAction->setDoAfter(editActionBaseWidget->theDoAfter->isChecked());
     } else if (editActionBaseWidget->theUseProfile->isChecked()) {
-        QString application = editActionBaseWidget->theApplications->itemData(editActionBaseWidget->theApplications->currentIndex()).toString();
-        QString function = editActionBaseWidget->theFunctions->itemData(editActionBaseWidget->theFunctions->currentIndex()).toString();
-        const ProfileAction *profileAction = ProfileServer::profileServer()->getAction(application, function);
-        if ( profileAction  || (editActionBaseWidget->theJustStart->isChecked() &&  ProfileServer::profileServer()->getProfileById(application))) {
-            tAction->setProgram(ProfileServer::profileServer()->getProfileById(application)->id());
+        QString application = editActionBaseWidget->theApplications->itemData(editActionBaseWidget->theApplications->currentIndex()).toString();       
+        ProfileAction *profileAction = profileModel->getProfileAction(editActionBaseWidget->theFunctions->currentIndex());
+        if ( profileAction  || (editActionBaseWidget->theJustStart->isChecked() &&  ProfileServer::getInstance()->getProfileById(application))) {
+            tAction->setProgram(ProfileServer::getInstance()->getProfileById(application)->id());
             if (editActionBaseWidget->theJustStart->isChecked()) {
                 tAction->setObject("");
             } else {
@@ -229,9 +230,7 @@ void EditAction::updateArguments()
     argumentsModel->setHorizontalHeaderLabels(headerLabels);
 
     if (editActionBaseWidget->theUseProfile->isChecked()) {
-        QString function = editActionBaseWidget->theFunctions->itemData(editActionBaseWidget->theFunctions->currentIndex()).toString();
-        QString application = editActionBaseWidget->theApplications->itemData(editActionBaseWidget->theApplications->currentIndex()).toString();
-        const ProfileAction *profileAction = ProfileServer::profileServer()->getAction(application, function);
+        ProfileAction *profileAction = profileModel->getProfileAction(editActionBaseWidget->theFunctions->currentIndex());
 
         // No profile action configured or theJustStart is checked... No need for arguments
         if (!profileAction ||  editActionBaseWidget->theJustStart->isChecked()) {
@@ -244,42 +243,41 @@ void EditAction::updateArguments()
                 profileAction->name() == theAction->function())
         {
             for (int i = 0; i < profileAction->arguments().count(); ++i) {
-                QList<QStandardItem*> tmp;
-                tmp.append(new ArgumentsModelItem(profileAction->arguments().at(i).comment() + " (" + profileAction->arguments().at(i).type() + ')'));
-                tmp.append(new ArgumentsModelItem(theAction->arguments().at(i)));
-                argumentsModel->appendRow(tmp);
+                QList<QStandardItem*> tItemList;
+                tItemList.append(new ArgumentsModelItem(profileAction->arguments().at(i).comment() + " (" + profileAction->arguments().at(i).type() + ')'));
+                tItemList.append(new ArgumentsModelItem(theAction->arguments().at(i)));
+                argumentsModel->appendRow(tItemList);
             }
 
         } else {
             const QList<ProfileActionArgument> &profileActionArguments = profileAction->arguments();
             for (int i = 0; i < profileActionArguments.count(); ++i) {
-                QList<QStandardItem*> tmp;
-                tmp.append(new ArgumentsModelItem(profileActionArguments.at(i).comment() + " (" + profileActionArguments.at(i).type() + ')'));
-                tmp.append(new ArgumentsModelItem(profileActionArguments.at(i).getDefault()));
-                argumentsModel->appendRow(tmp);
+                QList<QStandardItem*> tItemlist;
+                tItemlist.append(new ArgumentsModelItem(profileActionArguments.at(i).comment() + " (" + profileActionArguments.at(i).type() + ')'));
+                tItemlist.append(new ArgumentsModelItem(profileActionArguments.at(i).getDefault()));
+                argumentsModel->appendRow(tItemlist);
             }
         }
     } else if ( editActionBaseWidget->theUseDBus->isChecked()) {
         Prototype p = editActionBaseWidget->theDBusFunctions->itemData(editActionBaseWidget->theDBusFunctions->currentIndex(), Qt::UserRole).value<Prototype>();
 
-
         // Check if the current selected function is the configured one
-        if (!ProfileServer::profileServer()->getAction(theAction->program(), theAction->object(), theAction->method().prototype()) &&
+        if (!ProfileServer::getInstance()->getAction(theAction->program(), theAction->object(), theAction->method().prototype()) &&
                 getCurrentDbusApp() == theAction->program() && // The correct app is selected!
                 editActionBaseWidget->theDBusObjects->currentText() == theAction->object() && // And the Object is selected too!
                 getCurrentDBusFunction() == theAction->method().prototype()) { // And also the Function. Fill in the arguments
             for (int i = 0; i < theAction->arguments().size(); ++i) {
-                QList<QStandardItem*> tmp;
-                tmp.append(new ArgumentsModelItem(p.getArguments().at(i).second + " (" + QVariant::typeToName(p.getArguments().at(i).first) + ')'));
-                tmp.append(new ArgumentsModelItem(theAction->arguments().at(i)));
-                argumentsModel->appendRow(tmp);
+                QList<QStandardItem*> tItemlist;
+                tItemlist.append(new ArgumentsModelItem(p.getArguments().at(i).second + " (" + QVariant::typeToName(p.getArguments().at(i).first) + ')'));
+                tItemlist.append(new ArgumentsModelItem(theAction->arguments().at(i)));
+                argumentsModel->appendRow(tItemlist);
             }
         } else {
             for (int i = 0; i < p.getArguments().size(); ++i) {
-                QList<QStandardItem*> tmp;
-                tmp.append(new ArgumentsModelItem(p.getArguments().at(i).second + " (" + QVariant::typeToName(p.getArguments().at(i).first) + ')'));
-                tmp.append(new ArgumentsModelItem(QVariant(p.getArguments().at(i).first)));
-                argumentsModel->appendRow(tmp);
+                QList<QStandardItem*> tItemlist;
+                tItemlist.append(new ArgumentsModelItem(p.getArguments().at(i).second + " (" + QVariant::typeToName(p.getArguments().at(i).first) + ')'));
+                tItemlist.append(new ArgumentsModelItem(QVariant(p.getArguments().at(i).first)));
+                argumentsModel->appendRow(tItemlist);
             }
         }
     }
@@ -291,7 +289,7 @@ void EditAction::updateArguments()
 void EditAction::updateInstancesOptions()
 {
     if (editActionBaseWidget->theUseProfile->isChecked()) {
-        ProfileServer *theServer = ProfileServer::profileServer();
+        ProfileServer *theServer = ProfileServer::getInstance();
         if (editActionBaseWidget->theApplications->currentIndex() == -1) return;
         const Profile *p = theServer->getProfileById(editActionBaseWidget->theApplications->itemData(editActionBaseWidget->theApplications->currentIndex()).toString());
         isUnique = p->unique();
@@ -315,12 +313,12 @@ void EditAction::updateInstancesOptions()
 void EditAction::updateApplications()
 {
     editActionBaseWidget->theApplications->clear();
-    foreach(Profile *tmp, ProfileServer::profileServer()->profiles()) {
+    foreach(Profile *tmp, ProfileServer::getInstance()->profiles()) {
         editActionBaseWidget->theApplications->addItem(tmp->name(), tmp->id());
     }
     editActionBaseWidget->theApplications->model()->sort(0);
 
-    const ProfileAction *profileAction = ProfileServer::profileServer()->getAction(theAction->program(), theAction->object(), theAction->method().prototype());
+    const ProfileAction *profileAction = ProfileServer::getInstance()->getAction(theAction->program(), theAction->object(), theAction->method().prototype());
     if (profileAction) {
         int index = editActionBaseWidget->theApplications->findText(profileAction->profile()->name());
         editActionBaseWidget->theApplications->setCurrentIndex(index < 0 ? 0: index);
@@ -336,14 +334,11 @@ void EditAction::updateFunctions()
         return;
     }
 
-    const QString application = editActionBaseWidget->theApplications->itemData(editActionBaseWidget->theApplications->currentIndex()).toString();
-    kDebug() << "app:" << application;
-    QHash<QString, ProfileAction*> dict = ProfileServer::profileServer()->getProfileById(application)->actions();
-    QHash<QString, ProfileAction*>::const_iterator i;
-    for (i = dict.constBegin(); i != dict.constEnd(); ++i) {
-        editActionBaseWidget->theFunctions->addItem(i.value()->name(), i.key());
-    }
-    const ProfileAction *action = ProfileServer::profileServer()->getAction(theAction->program(), theAction->object(), theAction->method().prototype());
+     const QString application = editActionBaseWidget->theApplications->itemData(editActionBaseWidget->theApplications->currentIndex()).toString();
+     Profile *tProfile =const_cast<Profile*> (ProfileServer::getInstance()->getProfileById(application));
+     profileModel = new ProfileModel(tProfile, editActionBaseWidget->theFunctions);
+     editActionBaseWidget->theFunctions->setModel(new ProfileModel(tProfile, editActionBaseWidget->theFunctions));
+     const ProfileAction *action = ProfileServer::getInstance()->getAction(theAction->program(), theAction->object(), theAction->method().prototype());   
     if (action && (action->profile()->name() == editActionBaseWidget->theApplications->currentText())) {
         int index = editActionBaseWidget->theFunctions->findText(action->name());
         editActionBaseWidget->theFunctions->setCurrentIndex(index < 0 ? 0 : index);
@@ -361,7 +356,7 @@ void EditAction::updateDBusApplications()
         dbusServiceModel->appendRow(new DBusServiceItem(item));
     }
 
-    if (!ProfileServer::profileServer()->getAction(theAction->program(), theAction->object(), theAction->method().prototype()) &&
+    if (!ProfileServer::getInstance()->getAction(theAction->program(), theAction->object(), theAction->method().prototype()) &&
             !DBusInterface::getInstance()->isProgramRunning(theAction->program()) && 
 	    !theAction->isModeChange()) {
         dbusServiceModel->appendRow(new DBusServiceItem(theAction->program()));
@@ -378,7 +373,7 @@ void EditAction::updateDBusObjects()
     editActionBaseWidget->theDBusObjects->insertItems(0, DBusInterface::getInstance()->getObjects(getCurrentDbusApp()));
     kDebug() << "Currnet app " << getCurrentDbusApp();
     // Check if configured Action is a DBus Action but not running
-    if (!ProfileServer::profileServer()->getAction(theAction->program(), theAction->object(), theAction->method().prototype()) &&
+    if (!ProfileServer::getInstance()->getAction(theAction->program(), theAction->object(), theAction->method().prototype()) &&
             !DBusInterface::getInstance()->isProgramRunning(theAction->program())) {
         if (editActionBaseWidget->theDBusApplications->itemData(editActionBaseWidget->theDBusApplications->currentIndex()).toString() ==
                 theAction->program()) { // Is selected!
@@ -401,7 +396,7 @@ void EditAction::updateDBusFunctions()
     }
 
     // Check if configured Action is a DBus Action but not running
-    if (!ProfileServer::profileServer()->getAction(theAction->program(), theAction->object(), theAction->method().prototype()) &&
+    if (!ProfileServer::getInstance()->getAction(theAction->program(), theAction->object(), theAction->method().prototype()) &&
             !DBusInterface::getInstance()->isProgramRunning(theAction->program())) {
         if (editActionBaseWidget->theDBusApplications->itemData(editActionBaseWidget->theDBusApplications->currentIndex()).toString() ==
                 theAction->program()) { // The correct app is selected!
@@ -435,4 +430,8 @@ Arguments EditAction::getCurrentArgs() {
     return retList;
 }
 
+void EditAction::tryAction() {
+    DBusInterface::getInstance()->executeAction(*getAction());
+}
+
 #include "editaction.moc"
