@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2007 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
@@ -104,36 +104,24 @@ GPGProc::recode(QByteArray a, const bool colons)
 		if (pos > a.length() - 4)
 			break;
 
-		char c1, c2;
-		c1 = a[pos + 2];
-		c2 = a[pos + 3];
+		const QByteArray pattern(a.mid(pos, 4));
+		const QByteArray hexnum(pattern.right(2));
+		bool ok;
+		char n[2];
+		n[0] = hexnum.toUShort(&ok, 16);
+		n[1] = '\0';	// to use n as a 0-terminated string
+		if (!ok)
+			continue;
 
 		// ':' must be skipped, it is used as colon delimiter
 		// since it is pure ascii it can be replaced in QString.
-		if (!colons && (c1 == '3') && ((c2 == 'a') || (c2 == 'A'))) {
+		if (!colons && (n[0] == ':')) {
 			pos += 3;
 			continue;
 		}
 
-		if (!isxdigit(c1) || !isxdigit(c2))
-			continue;
-
-		char n[2] = { 0, 0 };
-
-		if (isdigit(c1))
-			n[0] = c1 - '0';
-		else
-			n[0] = tolower(c1) - 'a' + 10;
-		n[0] *= 16;
-
-		if (isdigit(c2))
-			n[0] += c2 - '0';
-		else
-			n[0] += tolower(c2) - 'a' + 10;
-
 		// it is likely to find the same byte sequence more than once
 		int npos = pos;
-		QByteArray pattern = a.mid(pos, 4);
 		do {
 			a.replace(npos, 4, n);
 		} while ((npos = a.indexOf(pattern, npos)) >= 0);
