@@ -38,7 +38,6 @@
 using namespace KgpgCore;
 
 KgpgLibrary::KgpgLibrary(QWidget *parent)
-	: m_pop(NULL)
 {
 	m_extension = ".gpg";
 
@@ -57,11 +56,8 @@ void KgpgLibrary::slotFileEnc(const KUrl::List &urls, const QStringList &opts, K
 		return;
 
 	m_urlselecteds = urls;
-	QString fileNames(urls.first().fileName());
-	if (urls.count() > 1)
-		fileNames += ", ...";	// FIXME
 
-	KgpgSelectPublicKeyDlg *dialog = new KgpgSelectPublicKeyDlg(0, model, goDefaultKey, fileNames);
+	QPointer<KgpgSelectPublicKeyDlg> dialog = new KgpgSelectPublicKeyDlg(0, model, goDefaultKey, false, urls);
 	if (dialog->exec() == KDialog::Accepted) {
 		QStringList options(opts);
 		if (dialog->getUntrusted())
@@ -113,13 +109,15 @@ void KgpgLibrary::fastEncode(const KUrl &filetocrypt, const QStringList &encrypt
 
 	QFile fgpg(dest.path());
 	if (fgpg.exists()) {
-		KIO::RenameDialog over(0, i18n("File Already Exists"), KUrl(), dest, KIO::M_OVERWRITE);
-		if (over.exec() == QDialog::Rejected) {
+		QPointer<KIO::RenameDialog> over = new KIO::RenameDialog(0, i18n("File Already Exists"), KUrl(), dest, KIO::M_OVERWRITE);
+		if (over->exec() == QDialog::Rejected) {
 			emit systemMessage(QString(), true);
 			return;
 		}
 
-		dest = over.newDestUrl();
+		dest = over->newDestUrl();
+
+		delete over;
 	}
 
 	int filesToEncode = m_urlselecteds.count();
@@ -166,14 +164,12 @@ void KgpgLibrary::slotFileDec(const KUrl &src, const KUrl &dest, const QStringLi
 	connect(decryptFileProcess, SIGNAL(decryptFileStarted(KUrl)), SLOT(processEncPopup(KUrl)));
 	connect(decryptFileProcess, SIGNAL(decryptFileFinished(int, KGpgTextInterface*)), SLOT(processDecOver(int, KGpgTextInterface*)));
 	decryptFileProcess->decryptFile(src, dest, customDecryptOption);
-
 }
 
 void KgpgLibrary::processDecOver(int ret, KGpgTextInterface *iface)
 {
 	emit systemMessage(QString());
 	delete m_pop;
-	m_pop = NULL;
 	iface->deleteLater();
 	if (ret != 0)
 		emit decryptionOver(this, m_urlselected);
