@@ -30,8 +30,8 @@
 #include "controller/zoomwheelcontroller.h"
 // Okteta core
 #include <valuecodec.h>
-#include <kbookmarkable.h>
-#include <kversionable.h>
+#include <bookmarkable.h>
+#include <versionable.h>
 #include <wordbytearrayservice.h>
 #include <arraychangemetricslist.h>
 #include <bookmark.h>
@@ -49,11 +49,11 @@
 #include <QtCore/QByteArray>
 
 
-namespace KHEUI
+namespace Okteta
 {
 
-static const int DefaultStartOffset = 0;//5;
-static const int DefaultFirstLineOffset = 0;
+static const Address DefaultStartOffset = 0;//5;
+static const Address DefaultFirstLineOffset = 0;
 static const int DefaultNoOfBytesPerLine =  16;
 
 // zooming is done in steps of font size points
@@ -64,56 +64,56 @@ static const int MaxFontPointSize = 128;
 static const AbstractByteArrayView::ValueCoding DefaultValueCoding =  AbstractByteArrayView::HexadecimalCoding;
 static const AbstractByteArrayView::CharCoding DefaultCharCoding = AbstractByteArrayView::LocalEncoding;
 
-static const AbstractByteArrayView::ResizeStyle DefaultResizeStyle = AbstractByteArrayView::FullSizeUsage;
+static const AbstractByteArrayView::LayoutStyle DefaultResizeStyle = AbstractByteArrayView::FullSizeLayoutStyle;
 
 static const char OctetStreamFormatName[] = "application/octet-stream";
 
 
-class NullModel : public KHECore::AbstractByteArrayModel
+class NullModel : public AbstractByteArrayModel
 {
   public:
     NullModel();
     virtual ~NullModel();
 
   public: // data access API
-    virtual char datum( unsigned int offset ) const;
-    virtual int size() const;
+    virtual Byte byte( Address offset ) const;
+    virtual Size size() const;
 
   public: // state read API
     virtual bool isModified() const;
 
   public: // modification API
-    virtual unsigned int replace( const KHE::Section& removeSection, const char* insertData, unsigned int insertLength );
-    virtual bool swap( int firstStart, const KHE::Section& secondSection );
-    virtual int fill( const char fillChar, unsigned int offset = 0, int fillLength = -1 );
-    virtual void setDatum( unsigned int offset, const char value );
+    virtual Size replace( const AddressRange& removeSection, const Byte* insertData, int insertLength );
+    virtual bool swap( Address firstStart, const AddressRange& secondRange);
+    virtual Size fill( Byte fillByte, Address offset = 0, Size fillLength = -1 );
+    virtual void setByte( Address offset, Byte byte );
     virtual void setModified( bool modified );
 };
 
 NullModel::NullModel() {}
 NullModel::~NullModel() {}
 
-char NullModel::datum( unsigned int offset ) const { Q_UNUSED(offset) return 0; }
-int NullModel::size() const { return 0; }
+Byte NullModel::byte( Address offset ) const { Q_UNUSED(offset) return 0; }
+Size NullModel::size() const { return 0; }
 bool NullModel::isModified() const { return false; }
-unsigned int NullModel::replace( const KHE::Section& removeSection, const char* insertData, unsigned int insertLength )
+Size NullModel::replace( const AddressRange& removeSection, const Byte* insertData, int insertLength )
 {
 Q_UNUSED(removeSection) Q_UNUSED(insertData) Q_UNUSED(insertLength)
     return 0;
 }
-bool NullModel::swap( int firstStart, const KHE::Section& secondSection )
+bool NullModel::swap( Address firstStart, const AddressRange& secondRange )
 {
-Q_UNUSED(firstStart) Q_UNUSED(secondSection)
+Q_UNUSED(firstStart) Q_UNUSED(secondRange)
     return false;
 }
-int NullModel::fill( const char fillChar, unsigned int offset, int fillLength )
+Size NullModel::fill( Byte fillByte, Address offset, Size fillLength )
 {
-Q_UNUSED(fillChar) Q_UNUSED(offset) Q_UNUSED(fillLength)
+Q_UNUSED(fillByte) Q_UNUSED(offset) Q_UNUSED(fillLength)
     return 0;
 }
-void NullModel::setDatum( unsigned int offset, const char value )
+void NullModel::setByte( Address offset, Byte byte )
 {
-Q_UNUSED(offset) Q_UNUSED(value)
+Q_UNUSED(offset) Q_UNUSED(byte)
 }
 void NullModel::setModified( bool modified )
 {
@@ -124,7 +124,7 @@ K_GLOBAL_STATIC( NullModel, nullModel )
 
 AbstractByteArrayViewPrivate::AbstractByteArrayViewPrivate( AbstractByteArrayView* parent )
  : mByteArrayModel( nullModel ),
-   mTableLayout( new ByteArrayTableLayout(DefaultNoOfBytesPerLine,DefaultFirstLineOffset,DefaultStartOffset,0) ),
+   mTableLayout( new ByteArrayTableLayout(DefaultNoOfBytesPerLine,DefaultFirstLineOffset,DefaultStartOffset,0,0) ),
    mTableCursor( new ByteArrayTableCursor(mTableLayout) ),
    mTableRanges( new ByteArrayTableRanges(mTableLayout) ),
    mReadOnly( false ),
@@ -148,9 +148,9 @@ void AbstractByteArrayViewPrivate::init()
     mTableLayout->setLength( mByteArrayModel->size() );
     mTableLayout->setNoOfLinesPerPage( q->noOfLinesPerPage() );
 
-    mValueCodec = KHECore::ValueCodec::createCodec( (KHECore::ValueCoding)DefaultValueCoding );
+    mValueCodec = ValueCodec::createCodec( (ValueCoding)DefaultValueCoding );
     mValueCoding = DefaultValueCoding;
-    mCharCodec = KHECore::CharCodec::createCodec( (KHECore::CharCoding)DefaultCharCoding );
+    mCharCodec = CharCodec::createCodec( (CharCoding)DefaultCharCoding );
     mCharCoding = DefaultCharCoding;
 
     mTabController = new KTabController( q, 0 );
@@ -163,7 +163,7 @@ void AbstractByteArrayViewPrivate::init()
     setWheelController( mZoomWheelController );
 }
 
-void AbstractByteArrayViewPrivate::setByteArrayModel( KHECore::AbstractByteArrayModel* byteArrayModel )
+void AbstractByteArrayViewPrivate::setByteArrayModel( AbstractByteArrayModel* byteArrayModel )
 {
     Q_Q( AbstractByteArrayView );
 
@@ -183,18 +183,18 @@ void AbstractByteArrayViewPrivate::setByteArrayModel( KHECore::AbstractByteArray
 
     q->connect( mByteArrayModel, SIGNAL(readOnlyChanged( bool )),
                 q, SLOT(onByteArrayReadOnlyChange( bool )) );
-    q->connect( mByteArrayModel, SIGNAL(contentsChanged( const KHE::ArrayChangeMetricsList& )),
-                q, SLOT(onContentsChanged( const KHE::ArrayChangeMetricsList& )) );
+    q->connect( mByteArrayModel, SIGNAL(contentsChanged( const Okteta::ArrayChangeMetricsList& )),
+                q, SLOT(onContentsChanged( const Okteta::ArrayChangeMetricsList& )) );
 
-    KHECore::Bookmarkable *bookmarks = qobject_cast<KHECore::Bookmarkable*>( mByteArrayModel );
+    Bookmarkable *bookmarks = qobject_cast<Bookmarkable*>( mByteArrayModel );
     if( bookmarks )
     {
-        q->connect( mByteArrayModel, SIGNAL(bookmarksAdded( const QList<KHECore::Bookmark>& )),
-                    q, SLOT(onBookmarksChange(const QList<KHECore::Bookmark>&)) );
-        q->connect( mByteArrayModel, SIGNAL(bookmarksRemoved( const QList<KHECore::Bookmark>& )),
-                    q, SLOT(onBookmarksChange(const QList<KHECore::Bookmark>&)) );
+        q->connect( mByteArrayModel, SIGNAL(bookmarksAdded( const QList<Okteta::Bookmark>& )),
+                    q, SLOT(onBookmarksChange(const QList<Okteta::Bookmark>&)) );
+        q->connect( mByteArrayModel, SIGNAL(bookmarksRemoved( const QList<Okteta::Bookmark>& )),
+                    q, SLOT(onBookmarksChange(const QList<Okteta::Bookmark>&)) );
     }
-    KHECore::Versionable* versionControl = qobject_cast<KHECore::Versionable*>( mByteArrayModel );
+    Versionable* versionControl = qobject_cast<Versionable*>( mByteArrayModel );
     if( versionControl )
     {
         q->connect( mByteArrayModel, SIGNAL(revertedToVersionIndex( int )),
@@ -308,7 +308,7 @@ void AbstractByteArrayViewPrivate::setZoomLevel( double zoomLevel )
 }
 
 
-void AbstractByteArrayViewPrivate::setStartOffset( int startOffset )
+void AbstractByteArrayViewPrivate::setStartOffset( Address startOffset )
 {
     Q_Q( AbstractByteArrayView );
 
@@ -328,7 +328,7 @@ void AbstractByteArrayViewPrivate::setStartOffset( int startOffset )
     emit q->cursorPositionChanged( cursorPosition() );
 }
 
-void AbstractByteArrayViewPrivate::setFirstLineOffset( int firstLineOffset )
+void AbstractByteArrayViewPrivate::setFirstLineOffset( Address firstLineOffset )
 {
     Q_Q( AbstractByteArrayView );
 
@@ -348,21 +348,21 @@ void AbstractByteArrayViewPrivate::setFirstLineOffset( int firstLineOffset )
     emit q->cursorPositionChanged( cursorPosition() );
 }
 
-void AbstractByteArrayViewPrivate::setResizeStyle( AbstractByteArrayView::ResizeStyle resizeStyle )
+void AbstractByteArrayViewPrivate::setLayoutStyle( AbstractByteArrayView::LayoutStyle layoutStyle )
 {
-    const bool isChanged = ( mResizeStyle != resizeStyle );
+    const bool isChanged = ( mResizeStyle != layoutStyle );
 
     if( !isChanged )
         return;
 
-    mResizeStyle = resizeStyle;
+    mResizeStyle = layoutStyle;
     updateViewByWidth();
 }
 
 void AbstractByteArrayViewPrivate::setNoOfBytesPerLine( int noOfBytesPerLine )
 {
     // if the number is explicitly set we expect a wish for no automatic resize
-    setResizeStyle( AbstractByteArrayView::NoResize );
+    setLayoutStyle( AbstractByteArrayView::FixedLayoutStyle );
 
     if( !mTableLayout->setNoOfBytesPerLine(noOfBytesPerLine) )
         return;
@@ -433,8 +433,8 @@ void AbstractByteArrayViewPrivate::setValueCoding( AbstractByteArrayView::ValueC
     if( mValueCoding == valueCoding )
         return;
 
-    KHECore::ValueCodec* newValueCodec
-        = KHECore::ValueCodec::createCodec( (KHECore::ValueCoding)valueCoding );
+    ValueCodec* newValueCodec
+        = ValueCodec::createCodec( (ValueCoding)valueCoding );
     if( newValueCodec == 0 )
         return;
 
@@ -447,8 +447,8 @@ void AbstractByteArrayViewPrivate::setCharCoding( AbstractByteArrayView::CharCod
     if( mCharCoding == charCoding )
         return;
 
-    KHECore::CharCodec* newCharCodec
-        = KHECore::CharCodec::createCodec( (KHECore::CharCoding)charCoding );
+    CharCodec* newCharCodec
+        = CharCodec::createCodec( (CharCoding)charCoding );
     if( newCharCodec == 0 )
         return;
 
@@ -461,8 +461,8 @@ void AbstractByteArrayViewPrivate::setCharCoding( const QString& charCodingName
     if( mCharCodec->name() == charCodingName )
         return;
 
-    KHECore::CharCodec *newCharCodec =
-        KHECore::CharCodec::createCodec( charCodingName );
+    CharCodec *newCharCodec =
+        CharCodec::createCodec( charCodingName );
     if( newCharCodec == 0 )
         return;
 
@@ -471,18 +471,37 @@ void AbstractByteArrayViewPrivate::setCharCoding( const QString& charCodingName
     mCharCoding = AbstractByteArrayView::LocalEncoding; // TODO: add encoding no to every known codec
 }
 
+void AbstractByteArrayViewPrivate::setMarking( const AddressRange& _marking )
+{
+    AddressRange marking( _marking );
+    marking.restrictEndTo( mTableLayout->length()-1 );
 
-bool AbstractByteArrayViewPrivate::selectWord( /*unsigned TODO:change all unneeded signed into unsigned!*/ int index )
+    const AddressRange oldMarking = mTableRanges->marking();
+
+    if( marking == oldMarking )
+        return;
+
+    mTableRanges->setMarking( marking );
+
+    updateChanged();
+}
+
+
+// TODO: make this use select( start, end )
+bool AbstractByteArrayViewPrivate::selectWord( Address index )
 {
     Q_Q( AbstractByteArrayView );
 
     bool result = false;
+
     if( 0 <= index && index < mTableLayout->length()  )
     {
-        const KHECore::WordByteArrayService WBS( mByteArrayModel, mCharCodec );
-        const KHE::Section wordSection = WBS.wordSection( index );
+        const WordByteArrayService WBS( mByteArrayModel, mCharCodec );
+        const AddressRange wordSection = WBS.wordSection( index );
         if( wordSection.isValid() )
         {
+            const bool oldHasSelection = mTableRanges->hasSelection();
+
             pauseCursor();
             finishByteEditor();
 
@@ -491,7 +510,17 @@ bool AbstractByteArrayViewPrivate::selectWord( /*unsigned TODO:change all unneed
             updateChanged();
 
             unpauseCursor();
-            emit q->cursorPositionChanged( mTableCursor->realIndex() );
+
+            const bool newHasSelection = mTableRanges->hasSelection();
+            emit q->selectionChanged( wordSection );
+            if( oldHasSelection != newHasSelection )
+            {
+                if( !mOverWrite ) emit q->cutAvailable( newHasSelection );
+                emit q->copyAvailable( newHasSelection );
+                emit q->hasSelectedDataChanged( newHasSelection );
+            }
+            emit q->cursorPositionChanged( cursorPosition() );
+
             result = true;
         }
     }
@@ -499,16 +528,19 @@ bool AbstractByteArrayViewPrivate::selectWord( /*unsigned TODO:change all unneed
 }
 
 
+// TODO: make this use select( start, end )
 void AbstractByteArrayViewPrivate::selectAll( bool select )
 {
     Q_Q( AbstractByteArrayView );
 
+    const bool oldHasSelection = mTableRanges->hasSelection();
+
     pauseCursor();
     finishByteEditor();
 
     if( select )
     {
-        mTableRanges->setSelection( KHE::Section(0,mTableLayout->length()-1) );
+        mTableRanges->setSelection( AddressRange(0,mTableLayout->length()-1) );
         mTableCursor->gotoEnd();
     }
     else
@@ -518,21 +550,24 @@ void AbstractByteArrayViewPrivate::selectAll( bool select )
 
     unpauseCursor();
 
-    const bool hasSelection = mTableRanges->hasSelection();
-    const KHE::Section selection = mTableRanges->selection();
-    if( !mOverWrite ) emit q->cutAvailable( hasSelection );
-    emit q->copyAvailable( hasSelection );
-    emit q->selectionChanged( hasSelection );
-    emit q->selectionChanged( selection );
+    const bool newHasSelection = mTableRanges->hasSelection();
+    emit q->selectionChanged( mTableRanges->selection() );
+    if( oldHasSelection != newHasSelection )
+    {
+        if( !mOverWrite ) emit q->cutAvailable( newHasSelection );
+        emit q->copyAvailable( newHasSelection );
+        emit q->hasSelectedDataChanged( newHasSelection );
+    }
     emit q->cursorPositionChanged( cursorPosition() );
-    q->viewport()->setCursor( isEffectiveReadOnly() ? Qt::ArrowCursor : Qt::IBeamCursor );
 }
 
 
-void AbstractByteArrayViewPrivate::setCursorPosition( int index, bool behind )
+void AbstractByteArrayViewPrivate::setCursorPosition( Address index, bool behind )
 {
     Q_Q( AbstractByteArrayView );
 
+    const bool oldHasSelection = mTableRanges->hasSelection();
+
     pauseCursor();
     finishByteEditor();
 
@@ -546,14 +581,14 @@ void AbstractByteArrayViewPrivate::setCursorPosition( int index, bool behind )
     {
         updateChanged();
 
-        q->viewport()->setCursor( isEffectiveReadOnly() ? Qt::ArrowCursor : Qt::IBeamCursor );
-
-        const bool hasSelection = mTableRanges->hasSelection();
-        const KHE::Section selection = mTableRanges->selection();
-        if( !mOverWrite ) emit q->cutAvailable( hasSelection );
-        emit q->copyAvailable( hasSelection );
-        emit q->selectionChanged( hasSelection );
-        emit q->selectionChanged( selection );
+        const bool newHasSelection = mTableRanges->hasSelection();
+        emit q->selectionChanged( mTableRanges->selection() );
+        if( oldHasSelection != newHasSelection )
+        {
+            if( !mOverWrite ) emit q->cutAvailable( newHasSelection );
+            emit q->copyAvailable( newHasSelection );
+            emit q->hasSelectedDataChanged( newHasSelection );
+        }
     }
     ensureCursorVisible();
 
@@ -563,7 +598,7 @@ void AbstractByteArrayViewPrivate::setCursorPosition( int index, bool behind )
 
 
 
-void AbstractByteArrayViewPrivate::setSelectionCursorPosition( int index )
+void AbstractByteArrayViewPrivate::setSelectionCursorPosition( Address index )
 {
     Q_Q( AbstractByteArrayView );
 
@@ -588,28 +623,39 @@ void AbstractByteArrayViewPrivate::setSelectionCursorPosition( int index )
 }
 
 
-void AbstractByteArrayViewPrivate::setSelection( int start, int end )
+
+void AbstractByteArrayViewPrivate::setSelection( const AddressRange& _selection )
 {
     Q_Q( AbstractByteArrayView );
 
-    if( start >= 0 && end < mTableLayout->length()  )
-    {
-        const KHE::Section selection( start, end );
-        if( selection.isValid() )
-        {
-            pauseCursor();
-            finishByteEditor();
+    AddressRange selection( _selection );
+    selection.restrictEndTo( mTableLayout->length()-1 );
 
-            mTableRanges->setSelection( selection );
-            mTableCursor->gotoCIndex( selection.nextBehindEnd() );
+    const AddressRange oldSelection = mTableRanges->selection();
+
+    if( ! selection.isValid()
+        || selection == oldSelection )
+        return;
+
+    pauseCursor();
+    finishByteEditor();
+
+    mTableRanges->setSelection( selection );
+    mTableCursor->gotoCIndex( selection.nextBehindEnd() );
 // TODO:            ensureVisible( *mActiveColumn, mTableLayout->coordOfIndex(selection.start()) );
-            ensureCursorVisible();
-            updateChanged();
+    ensureCursorVisible();
+    updateChanged();
 
-            unpauseCursor();
-            emit q->cursorPositionChanged( cursorPosition() );
-        }
+    unpauseCursor();
+
+    emit q->selectionChanged( selection );
+    if( oldSelection.isEmpty() )
+    {
+        if( !mOverWrite ) emit q->cutAvailable( true );
+        emit q->copyAvailable( true );
+        emit q->hasSelectedDataChanged( true );
     }
+    emit q->cursorPositionChanged( cursorPosition() );
 }
 
 
@@ -618,10 +664,10 @@ QByteArray AbstractByteArrayViewPrivate::selectedData() const
     if( !mTableRanges->hasSelection() )
         return QByteArray();
 
-    const KHE::Section selection = mTableRanges->selection();
+    const AddressRange selection = mTableRanges->selection();
     QByteArray data;
     data.resize( selection.width() );
-    byteArrayModel()->copyTo( data.data(), selection.start(), selection.width() );
+    byteArrayModel()->copyTo( reinterpret_cast<Byte*>(data.data()), selection.start(), selection.width() );
     return data;
 }
 
@@ -676,14 +722,15 @@ void AbstractByteArrayViewPrivate::pasteData( const QMimeData* data )
     if( ! data || data->formats().isEmpty() )
         return;
 
+    // SYNC: with bytearraydocumentfactory.cpp
     // if there is a octet stream, use it, otherwise take the dump of the format
     // with the highest priority
     // TODO: this may not be, what is expected, think about it, if we just
     // take byte array descriptions, like encodings in chars or values
     // would need the movement of the encoders into the core library
-    const QLatin1String octetStreamFormatName( OctetStreamFormatName );
+    const QString octetStreamFormatName = QString::fromLatin1( OctetStreamFormatName );
     const QString dataFormatName = ( data->hasFormat(octetStreamFormatName) ) ?
-        QString( octetStreamFormatName ) :
+        octetStreamFormatName :
         data->formats()[0];
 
     const QByteArray byteArray = data->data( dataFormatName );
@@ -704,26 +751,28 @@ void AbstractByteArrayViewPrivate::insert( const QByteArray& data )
 {
     Q_Q( AbstractByteArrayView );
 
+    const bool oldHasSelection = mTableRanges->hasSelection();
+
     if( mOverWrite )
     {
-        int lengthOfInserted;
+        Size lengthOfInserted;
         if( mTableRanges->hasSelection() )
         {
             // replacing the selection:
             // we restrict the replacement to the minimum length of selection and input
-            KHE::Section selection = mTableRanges->removeSelection();
+            AddressRange selection = mTableRanges->removeSelection();
             selection.restrictEndByWidth( data.size() );
-            lengthOfInserted = mByteArrayModel->replace( selection, data.data(), selection.width() );
+            lengthOfInserted = mByteArrayModel->replace( selection, reinterpret_cast<const Byte*>(data.constData()), selection.width() );
         }
         else
         {
-            const int length = mTableLayout->length();
+            const Size length = mTableLayout->length();
             if( !isCursorBehind() && length > 0 )
             {
                 // replacing the normal data, at least until the end
-                KHE::Section insertRange = KHE::Section::fromWidth( cursorPosition(), data.size() );
+                AddressRange insertRange = AddressRange::fromWidth( cursorPosition(), data.size() );
                 insertRange.restrictEndTo( length-1 );
-                lengthOfInserted = mByteArrayModel->replace( insertRange, data.data(), insertRange.width() );
+                lengthOfInserted = mByteArrayModel->replace( insertRange, reinterpret_cast<const Byte*>(data.constData()), insertRange.width() );
             }
             else
                 lengthOfInserted = 0;
@@ -742,15 +791,17 @@ void AbstractByteArrayViewPrivate::insert( const QByteArray& data )
         if( mTableRanges->hasSelection() )
         {
             // replacing the selection
-            const KHE::Section selection = mTableRanges->removeSelection();
+            const AddressRange selection = mTableRanges->removeSelection();
             mByteArrayModel->replace( selection, data );
         }
         else
             mByteArrayModel->insert( cursorPosition(), data );
     }
 
-    emit q->selectionChanged( mTableRanges->hasSelection() );
+    const bool newHasSelection = mTableRanges->hasSelection();
     emit q->selectionChanged( mTableRanges->selection() );
+    if( oldHasSelection != newHasSelection )
+        emit q->hasSelectedDataChanged( newHasSelection );
 }
 
 
@@ -760,7 +811,7 @@ void AbstractByteArrayViewPrivate::removeSelectedData()
     if( isEffectiveReadOnly() || mOverWrite ) //TODO: || mValueEditor->isInEditMode() )
         return;
 
-    const KHE::Section selection = mTableRanges->removeSelection();
+    const AddressRange selection = mTableRanges->removeSelection();
 
     mByteArrayModel->remove( selection );
 
@@ -769,7 +820,7 @@ void AbstractByteArrayViewPrivate::removeSelectedData()
   //emit q->selectionChanged( -1, -1 );
 }
 
-bool AbstractByteArrayViewPrivate::hasChanged( const CoordRange& visibleRange, CoordRange* changedRange ) const
+bool AbstractByteArrayViewPrivate::getNextChangedRange( CoordRange* changedRange, const CoordRange& visibleRange ) const
 {
     const bool result = mTableRanges->overlapsChanges( visibleRange, changedRange );
 
@@ -801,7 +852,10 @@ void AbstractByteArrayViewPrivate::updateViewByWidth()
     q->viewport()->update();
 
     mTableCursor->updateCoord();
-    ensureCursorVisible();
+    // TODO: see for what actions if would be usable to have ensureCursorVisible()
+    // TODO: think about adding action "showCursor"/"show FocusItem" to menu
+    // disabled as this prevents splitting views with aligned areas from working
+    // ensureCursorVisible();
 
     unpauseCursor();
     emit q->cursorPositionChanged( cursorPosition() );
@@ -813,7 +867,7 @@ void AbstractByteArrayViewPrivate::adjustLayoutToSize()
     Q_Q( AbstractByteArrayView );
 
     // check whether there is a change with the numbers of fitting bytes per line
-    if( mResizeStyle != AbstractByteArrayView::NoResize )
+    if( mResizeStyle != AbstractByteArrayView::FixedLayoutStyle )
     {
         // changes?
         if( mTableLayout->setNoOfBytesPerLine(fittingBytesPerLine()) )
@@ -852,10 +906,10 @@ bool AbstractByteArrayViewPrivate::viewportEvent( QEvent* event )
 
         QString toolTip;
 
-        KHECore::Bookmarkable* bookmarks = qobject_cast<KHECore::Bookmarkable*>( mByteArrayModel );
+        Bookmarkable* bookmarks = qobject_cast<Bookmarkable*>( mByteArrayModel );
         if( bookmarks )
         {
-            const int index = indexByPoint( q->viewportToColumns(helpEvent->pos()) );
+            const Address index = indexByPoint( q->viewportToColumns(helpEvent->pos()) );
             if( index != -1 )
             {
                 if( bookmarks->containsBookmarkFor(index) )
@@ -881,7 +935,7 @@ void AbstractByteArrayViewPrivate::resizeEvent( QResizeEvent* resizeEvent )
 {
     Q_Q( AbstractByteArrayView );
 
-    if( mResizeStyle != AbstractByteArrayView::NoResize )
+    if( mResizeStyle != AbstractByteArrayView::FixedLayoutStyle )
     {
         // changes?
         if( mTableLayout->setNoOfBytesPerLine(fittingBytesPerLine()) )
@@ -902,6 +956,11 @@ void AbstractByteArrayViewPrivate::focusInEvent( QFocusEvent* focusEvent )
 
     q->ColumnsView::focusInEvent( focusEvent );
     startCursor();
+
+    const Qt::FocusReason focusReason = focusEvent->reason();
+    if( focusReason != Qt::ActiveWindowFocusReason
+        && focusReason != Qt::PopupFocusReason )
+        emit q->focusChanged( true );
 }
 
 void AbstractByteArrayViewPrivate::focusOutEvent( QFocusEvent* focusEvent )
@@ -910,6 +969,11 @@ void AbstractByteArrayViewPrivate::focusOutEvent( QFocusEvent* focusEvent )
 
     stopCursor();
     q->ColumnsView::focusOutEvent( focusEvent );
+
+    const Qt::FocusReason focusReason = focusEvent->reason();
+    if( focusReason != Qt::ActiveWindowFocusReason
+        && focusReason != Qt::PopupFocusReason )
+        emit q->focusChanged( false );
 }
 
 
@@ -946,11 +1010,11 @@ void AbstractByteArrayViewPrivate::dropEvent( QDropEvent* dropEvent )
 }
 
 
-void AbstractByteArrayViewPrivate::onBookmarksChange( const QList<KHECore::Bookmark>& bookmarks )
+void AbstractByteArrayViewPrivate::onBookmarksChange( const QList<Bookmark>& bookmarks )
 {
-    foreach( const KHECore::Bookmark& bookmark, bookmarks )
+    foreach( const Bookmark& bookmark, bookmarks )
     {
-        const int position = bookmark.offset();
+        const Address position = bookmark.offset();
         mTableRanges->addChangedRange( position, position );
     }
 
@@ -975,14 +1039,14 @@ void AbstractByteArrayViewPrivate::onByteArrayReadOnlyChange( bool isByteArrayRe
 }
 
 
-void AbstractByteArrayViewPrivate::onContentsChanged( const KHE::ArrayChangeMetricsList& changeList )
+void AbstractByteArrayViewPrivate::onContentsChanged( const ArrayChangeMetricsList& changeList )
 {
     Q_Q( AbstractByteArrayView );
 
     pauseCursor();
 
     const bool atEnd = mTableCursor->atEnd();
-    const int oldLength = mTableLayout->length(); // TODO: hack for mDataCursor->adaptSelectionToChange
+    const Size oldLength = mTableLayout->length(); // TODO: hack for mDataCursor->adaptSelectionToChange
     // update lengths
     int oldNoOfLines = q->noOfLines();
     mTableLayout->setLength( mByteArrayModel->size() );
@@ -990,9 +1054,9 @@ void AbstractByteArrayViewPrivate::onContentsChanged( const KHE::ArrayChangeMetr
     if( oldNoOfLines != newNoOfLines )
     {
         q->setNoOfLines( newNoOfLines );
-        const KHE::Section changedLines = (oldNoOfLines < newNoOfLines) ?
-            KHE::Section( oldNoOfLines, newNoOfLines-1 ) :
-            KHE::Section( newNoOfLines, oldNoOfLines-1 );
+        const LineRange changedLines = (oldNoOfLines < newNoOfLines) ?
+            LineRange( oldNoOfLines, newNoOfLines-1 ) :
+            LineRange( newNoOfLines, oldNoOfLines-1 );
         mTableRanges->addChangedOffsetLines( changedLines );
     }
 
