@@ -24,6 +24,7 @@
 
 // lib
 #include "bordercolumnrenderer.h"
+#include "widgetcolumnstylist.h"
 #include "bytearraytableranges.h"
 #include "bytearraytablelayout.h"
 #include "controller/kvalueeditor.h"
@@ -48,7 +49,7 @@
 #include <QtCore/QTimer>
 
 
-namespace KHEUI
+namespace Okteta
 {
 static const int DefaultScrollTimerPeriod = 100;
 static const int InsertCursorWidth = 2;
@@ -74,20 +75,26 @@ void ByteArrayRowViewPrivate::init()
     mDragStartTimer = new QTimer( q );
     mTrippleClickTimer = new QTimer( q );
 
+    mStylist = new WidgetColumnStylist( q );
+
     // creating the columns in the needed order
     mOffsetColumn =
-        new OffsetColumnRenderer( q, mTableLayout, KOffsetFormat::Hexadecimal );
+        new OffsetColumnRenderer( mStylist, mTableLayout, OffsetFormat::Hexadecimal );
     mBorderColumn =
-        new BorderColumnRenderer( q, false );
+        new BorderColumnRenderer( mStylist, false );
     mByteArrayColumn =
-        new ByteArrayRowColumnRenderer( q, mByteArrayModel, mTableLayout, mTableRanges );
+        new ByteArrayRowColumnRenderer( mStylist, mByteArrayModel, mTableLayout, mTableRanges );
+
+    q->addColumn( mOffsetColumn );
+    q->addColumn( mBorderColumn );
+    q->addColumn( mByteArrayColumn );
 
     // select the active column
     mActiveCoding = AbstractByteArrayView::CharCodingId;
     mInactiveCoding = AbstractByteArrayView::ValueCodingId;
 
     // set char encoding
-    mByteArrayColumn->setValueCodec( (KHECore::ValueCoding)mValueCoding, mValueCodec );
+    mByteArrayColumn->setValueCodec( (ValueCoding)mValueCoding, mValueCodec );
     mByteArrayColumn->setCharCodec( mCharCodec );
 //     mByteArrayColumn->setActiveCoding( mActiveCoding );
 
@@ -104,10 +111,10 @@ void ByteArrayRowViewPrivate::init()
     q->setAcceptDrops( true );
 }
 
-int ByteArrayRowViewPrivate::visibleCodings()                          const { return mByteArrayColumn->visibleCodings(); }
+AbstractByteArrayView::CodingTypes ByteArrayRowViewPrivate::visibleCodings() const { return mByteArrayColumn->visibleCodings(); }
 ByteArrayRowView::CodingTypeId ByteArrayRowViewPrivate::activeCoding() const { return mActiveCoding; }
 
-void ByteArrayRowViewPrivate::setByteArrayModel( KHECore::AbstractByteArrayModel* _byteArrayModel )
+void ByteArrayRowViewPrivate::setByteArrayModel( AbstractByteArrayModel* _byteArrayModel )
 {
     mValueEditor->reset();
 
@@ -118,7 +125,7 @@ void ByteArrayRowViewPrivate::setByteArrayModel( KHECore::AbstractByteArrayModel
 }
 
 
-void ByteArrayRowViewPrivate::setBufferSpacing( KPixelX ByteSpacing, int noOfGroupedBytes, KPixelX GroupSpacing )
+void ByteArrayRowViewPrivate::setBufferSpacing( PixelX ByteSpacing, int noOfGroupedBytes, PixelX GroupSpacing )
 {
     if( !mByteArrayColumn->setSpacing(ByteSpacing,noOfGroupedBytes,GroupSpacing) )
         return;
@@ -138,7 +145,7 @@ void ByteArrayRowViewPrivate::setValueCoding( AbstractByteArrayView::ValueCoding
 
     AbstractByteArrayViewPrivate::setValueCoding( valueCoding );
 
-    mByteArrayColumn->setValueCodec( (KHECore::ValueCoding)mValueCoding, mValueCodec );
+    mByteArrayColumn->setValueCodec( (ValueCoding)mValueCoding, mValueCodec );
     mValueEditor->adaptToValueCodecChange();
 
     const uint newCodingWidth = mValueCodec->encodingWidth();
@@ -153,7 +160,7 @@ void ByteArrayRowViewPrivate::setValueCoding( AbstractByteArrayView::ValueCoding
 }
 
 
-void ByteArrayRowViewPrivate::setByteSpacingWidth( int/*KPixelX*/ byteSpacingWidth )
+void ByteArrayRowViewPrivate::setByteSpacingWidth( int/*PixelX*/ byteSpacingWidth )
 {
     if( !mByteArrayColumn->setByteSpacingWidth(byteSpacingWidth) )
         return;
@@ -168,7 +175,7 @@ void ByteArrayRowViewPrivate::setNoOfGroupedBytes( int noOfGroupedBytes )
 }
 
 
-void ByteArrayRowViewPrivate::setGroupSpacingWidth( int/*KPixelX*/ groupSpacingWidth )
+void ByteArrayRowViewPrivate::setGroupSpacingWidth( int/*PixelX*/ groupSpacingWidth )
 {
     if( !mByteArrayColumn->setGroupSpacingWidth(groupSpacingWidth) )
         return;
@@ -176,7 +183,7 @@ void ByteArrayRowViewPrivate::setGroupSpacingWidth( int/*KPixelX*/ groupSpacingW
 }
 
 
-void ByteArrayRowViewPrivate::setBinaryGapWidth( int/*KPixelX*/ binaryGapWidth )
+void ByteArrayRowViewPrivate::setBinaryGapWidth( int/*PixelX*/ binaryGapWidth )
 {
     if( !mByteArrayColumn->setBinaryGapWidth(binaryGapWidth) )
         return;
@@ -282,9 +289,9 @@ void ByteArrayRowViewPrivate::handleFontChange( const QFont& oldFont )
 
     // get new values
     const QFontMetrics newFontMetrics = q->fontMetrics();
-    const KPixelX digitWidth = newFontMetrics.maxWidth();
-    const KPixelY digitBaseLine = newFontMetrics.ascent();
-    const KPixelY digitHeight = newFontMetrics.height();
+    const PixelX digitWidth = newFontMetrics.maxWidth();
+    const PixelY digitBaseLine = newFontMetrics.ascent();
+    const PixelY digitHeight = newFontMetrics.height();
 
     mOffsetColumn->setMetrics( digitWidth, digitBaseLine );
     mByteArrayColumn->setMetrics( digitWidth, digitBaseLine, digitHeight );
@@ -345,24 +352,24 @@ int ByteArrayRowViewPrivate::fittingBytesPerLine() const
     Q_Q( const ByteArrayRowView );
 
     const QSize newSize = q->maximumViewportSize();
-    const KPixelX reservedWidth =
+    const PixelX reservedWidth =
         mOffsetColumn->visibleWidth()
         + mBorderColumn->visibleWidth();
 
     // abstract offset and border columns width
-    const KPixelX fullWidth = newSize.width() - reservedWidth;
+    const PixelX fullWidth = newSize.width() - reservedWidth;
 
     //  // no width left for resizeable columns? TODO: put this in resizeEvent
     //  if( fullWidth < 0 )
     //    return;
 
-    const KPixelY fullHeight = newSize.height();
+    const PixelY fullHeight = newSize.height();
 
     // check influence of dis-/appearing of the vertical scrollbar
     const bool verticalScrollbarIsVisible = q->verticalScrollBar()->isVisible();
-    const KPixelX scrollbarExtent = q->style()->pixelMetric( QStyle::PM_ScrollBarExtent );
+    const PixelX scrollbarExtent = q->style()->pixelMetric( QStyle::PM_ScrollBarExtent );
 
-    KPixelX availableWidth = fullWidth;
+    PixelX availableWidth = fullWidth;
     if( verticalScrollbarIsVisible )
         availableWidth -= scrollbarExtent;
 
@@ -370,9 +377,9 @@ int ByteArrayRowViewPrivate::fittingBytesPerLine() const
     KMatchTrial matchRun = FirstRun;
 
     // prepare needed values
-    const KPixelX byteWidth = mByteArrayColumn->byteWidth();
-    const KPixelX byteSpacingWidth = mByteArrayColumn->byteSpacingWidth();
-    KPixelX groupSpacingWidth;
+    const PixelX byteWidth = mByteArrayColumn->byteWidth();
+    const PixelX byteSpacingWidth = mByteArrayColumn->byteSpacingWidth();
+    PixelX groupSpacingWidth;
     int noOfGroupedBytes = mByteArrayColumn->noOfGroupedBytes();
     // no grouping?
     if( noOfGroupedBytes == 0 )
@@ -384,8 +391,8 @@ int ByteArrayRowViewPrivate::fittingBytesPerLine() const
     else
         groupSpacingWidth = mByteArrayColumn->groupSpacingWidth();
 
-    const KPixelX byteGroupWidth =  noOfGroupedBytes * byteWidth + (noOfGroupedBytes-1)*byteSpacingWidth;
-    const KPixelX totalGroupWidth = byteGroupWidth + groupSpacingWidth;
+    const PixelX byteGroupWidth =  noOfGroupedBytes * byteWidth + (noOfGroupedBytes-1)*byteSpacingWidth;
+    const PixelX totalGroupWidth = byteGroupWidth + groupSpacingWidth;
 
     int fittingBytesPerLine;
     int fittingBytesPerLineWithScrollbar = 0;
@@ -406,7 +413,7 @@ int ByteArrayRowViewPrivate::fittingBytesPerLine() const
         fittingBytesPerLine = noOfGroupedBytes * fittingGroupsPerLine;
 
         // not only full groups?
-        if( mResizeStyle == AbstractByteArrayView::FullSizeUsage && noOfGroupedBytes > 1 )
+        if( mResizeStyle == AbstractByteArrayView::FullSizeLayoutStyle && noOfGroupedBytes > 1 )
         {
 
             if( fittingGroupsPerLine > 0 )
@@ -440,7 +447,7 @@ int ByteArrayRowViewPrivate::fittingBytesPerLine() const
 
         const int newNoOfLines = (mTableLayout->length()+mTableLayout->startOffset()+fittingBytesPerLine-1)
                                  / fittingBytesPerLine;
-        const KPixelY newHeight =  newNoOfLines * q->lineHeight();
+        const PixelY newHeight =  newNoOfLines * q->lineHeight();
 
         if( verticalScrollbarIsVisible )
         {
@@ -490,7 +497,7 @@ void ByteArrayRowViewPrivate::setVisibleCodings( int newCodings )
     const int oldCodings = visibleCodings();
 
     // no changes or no column selected?
-    if( newCodings == oldCodings || !(newCodings&AbstractByteArrayView::BothCodingsId) )
+    if( newCodings == oldCodings || !(newCodings&AbstractByteArrayView::ValueAndCharCodings) )
         return;
 
     mByteArrayColumn->setVisibleCodings( newCodings );
@@ -537,8 +544,8 @@ void ByteArrayRowViewPrivate::placeCursor( const QPoint& point )
     Q_Q( ByteArrayRowView );
 
     const int lineIndex = q->lineAt( point.y() );
-    const KPixelY lineY = lineIndex * q->lineHeight();
-    const KPixelY y = point.y() - lineY;
+    const PixelY lineY = lineIndex * q->lineHeight();
+    const PixelY y = point.y() - lineY;
 
     const AbstractByteArrayView::CodingTypeId codingId = mByteArrayColumn->codingIdofY( y );
 
@@ -561,7 +568,7 @@ void ByteArrayRowViewPrivate::placeCursor( const QPoint& point )
 }
 
 
-int ByteArrayRowViewPrivate::indexByPoint( const QPoint& point ) const
+Address ByteArrayRowViewPrivate::indexByPoint( const QPoint& point ) const
 {
     Q_Q( const ByteArrayRowView );
 
@@ -582,7 +589,7 @@ void ByteArrayRowViewPrivate::blinkCursor()
 
     // switch the cursor state
     mBlinkCursorVisible = !mBlinkCursorVisible;
-    updateCursor( *mByteArrayColumn );
+    updateCursor( *mByteArrayColumn, mActiveCoding );
 }
 
 
@@ -610,7 +617,8 @@ void ByteArrayRowViewPrivate::updateCursors()
     createCursorPixmaps();
 
     mBlinkCursorVisible = true;
-    updateCursor( *mByteArrayColumn );
+    updateCursor( *mByteArrayColumn, mActiveCoding );
+    updateCursor( *mByteArrayColumn, mInactiveCoding );
 }
 
 
@@ -627,36 +635,36 @@ void ByteArrayRowViewPrivate::pauseCursor()
     mCursorPaused = true;
 
     mBlinkCursorVisible = false;
-    updateCursor( *mByteArrayColumn );
+    updateCursor( *mByteArrayColumn, mActiveCoding );
+    updateCursor( *mByteArrayColumn, mInactiveCoding );
 }
 
+
 QRect ByteArrayRowViewPrivate::cursorRect() const
 {
     Q_Q( const ByteArrayRowView );
 
-    const int x = mByteArrayColumn->xOfLinePosition( mTableCursor->pos() ) - q->xOffset();
-    const int y = q->lineHeight() * mTableCursor->line()
-                  + mByteArrayColumn->yOfCodingId( mActiveCoding ) - q->yOffset();
-    const int w = mByteArrayColumn->byteWidth();
-    const int h = q->lineHeight();
-    const QPoint viewportPoint( x, y );
-    const QPoint point = q->viewport()->mapToParent( viewportPoint ); // TODO: seems still missing some offset
-    const QSize size( w, h );
+    QRect cursorRect = mByteArrayColumn->byteRect( mTableCursor->coord(), mActiveCoding );
+    const QPoint viewportPoint( cursorRect.x() - q->xOffset(), cursorRect.y() - q->yOffset() );
+    const QPoint globalPoint = q->viewport()->mapToParent( viewportPoint ); // TODO: seems still missing some offset
+    cursorRect.setTopLeft( globalPoint );
 
-    const QRect result( point, size );
-    return result;
+    return cursorRect;
 }
 
 // TODO: should be movable to base class
-void ByteArrayRowViewPrivate::updateCursor( const ByteArrayRowColumnRenderer& column )
+void ByteArrayRowViewPrivate::updateCursor( const ByteArrayRowColumnRenderer& column, AbstractByteArrayView::CodingTypeId codingId )
 {
     Q_Q( ByteArrayRowView );
 
-    const int x = column.xOfLinePosition( mTableCursor->pos() ) - q->xOffset();
-    const int y = q->lineHeight() * mTableCursor->line() - q->yOffset();
-    const int w = column.byteWidth();
+    const bool isCodingVisible = ( column.visibleCodings() & codingId );
+    if( ! isCodingVisible )
+        return;
 
-    q->viewport()->update( x,y, w,q->lineHeight() );
+    QRect cursorRect = column.byteRect( mTableCursor->coord(), codingId );
+    cursorRect.translate( -q->xOffset(), - q->yOffset() );
+
+    q->viewport()->update( cursorRect );
 }
 
 void ByteArrayRowViewPrivate::createCursorPixmaps()
@@ -666,7 +674,7 @@ void ByteArrayRowViewPrivate::createCursorPixmaps()
     // create mCursorPixmaps
     mCursorPixmaps->setSize( mByteArrayColumn->byteWidth(), mByteArrayColumn->digitHeight() );
 
-    const int index = mTableCursor->validIndex();
+    const Address index = mTableCursor->validIndex();
 
     QPainter painter;
     painter.begin( &mCursorPixmaps->offPixmap() );
@@ -680,8 +688,8 @@ void ByteArrayRowViewPrivate::createCursorPixmaps()
     painter.end();
 
     // calculat the shape
-    KPixelX cursorX;
-    KPixelX cursorW;
+    PixelX cursorX;
+    PixelX cursorW;
     if( isCursorBehind() )
     {
         cursorX = qMax( 0, mCursorPixmaps->onPixmap().width()-InsertCursorWidth );
@@ -713,7 +721,7 @@ void ByteArrayRowViewPrivate::drawActiveCursor( QPainter* painter )
     // paint edited byte?
     if( mValueEditor->isInEditMode() )
     {
-        const int index = mTableCursor->index();
+        const Address index = mTableCursor->index();
 
         if( mBlinkCursorVisible )
             mByteArrayColumn->renderEditedByte( painter, mValueEditor->value(), mValueEditor->valueAsString() );
@@ -739,7 +747,7 @@ void ByteArrayRowViewPrivate::drawInactiveCursor( QPainter* painter )
         || (!mCursorPaused && !q->hasFocus() && !q->viewport()->hasFocus() && !mDropper->isActive())  )
         return;
 
-    const int index = mTableCursor->validIndex();
+    const Address index = mTableCursor->validIndex();
 
     const int x = mByteArrayColumn->xOfLinePosition( mTableCursor->pos() );
     const int y = q->lineHeight() * mTableCursor->line()
@@ -765,7 +773,7 @@ void ByteArrayRowViewPrivate::renderColumns( QPainter* painter, int cx, int cy,
     // Then it needs to know about inactive, insideByte and the like... well...
     // perhaps subclassing the buffer columns even more, to CharByteArrayColumnRenderer and ValueByteArrayColumnRenderer?
 
-    if( q->visibleLines(KPixelYs::fromWidth(cy,ch)).includes(mTableCursor->line()) )
+    if( q->visibleLines(PixelYRange::fromWidth(cy,ch)).includes(mTableCursor->line()) )
     {
         drawActiveCursor( painter );
         drawInactiveCursor( painter );
@@ -777,10 +785,10 @@ void ByteArrayRowViewPrivate::updateChanged()
     Q_Q( ByteArrayRowView );
 
     const int xOffset = q->xOffset();
-    const KPixelXs Xs = KPixelXs::fromWidth( xOffset, q->visibleWidth() );
+    const PixelXRange Xs = PixelXRange::fromWidth( xOffset, q->visibleWidth() );
 
     // do updates in offset column 
-    const KHE::Section changedOffsetLines = mTableRanges->changedOffsetLines();
+    const LineRange changedOffsetLines = mTableRanges->changedOffsetLines();
     if( !changedOffsetLines.isEmpty() )
         q->updateColumn( *mOffsetColumn, changedOffsetLines );
 
@@ -797,24 +805,24 @@ void ByteArrayRowViewPrivate::updateChanged()
     if( dirtyColumns.size() > 0 )
     {
         // calculate affected lines/indizes
-        const KHE::Section fullPositions( 0, mTableLayout->noOfBytesPerLine()-1 );
+        const LinePositionRange fullPositions( 0, mTableLayout->noOfBytesPerLine()-1 );
         CoordRange visibleRange( fullPositions, q->visibleLines() );
 
         const int lineHeight = q->lineHeight();
         CoordRange changedRange;
         // as there might be multiple selections on this line redo until no more is changed
-        while( hasChanged(visibleRange,&changedRange) )
+        while( getNextChangedRange(&changedRange,visibleRange) )
         {
-            KPixelY cy = q->yOffsetOfLine( changedRange.start().line() );
+            PixelY cy = q->yOffsetOfLine( changedRange.start().line() );
 
             QListIterator<ByteArrayRowColumnRenderer*> columnIt( dirtyColumns );
             // only one line?
             if( changedRange.start().line() == changedRange.end().line() )
             {
-                const KHE::Section changedPositions( changedRange.start().pos(), changedRange.end().pos() );
+                const LinePositionRange changedPositions( changedRange.start().pos(), changedRange.end().pos() );
                 while( columnIt.hasNext() )
                 {
-                    const KPixelXs xPixels = columnIt.next()->xsOfLinePositionsInclSpaces( changedPositions );
+                    const PixelXRange xPixels = columnIt.next()->xsOfLinePositionsInclSpaces( changedPositions );
 
                     q->viewport()->update( xPixels.start()-xOffset, cy, xPixels.width(), lineHeight );
                 }
@@ -823,10 +831,10 @@ void ByteArrayRowViewPrivate::updateChanged()
             else
             {
                 // first line
-                const KHE::Section firstChangedPositions( changedRange.start().pos(), fullPositions.end() );
+                const LinePositionRange firstChangedPositions( changedRange.start().pos(), fullPositions.end() );
                 while( columnIt.hasNext() )
                 {
-                    const KPixelXs XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( firstChangedPositions );
+                    const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( firstChangedPositions );
 
                     q->viewport()->update( XPixels.start()-xOffset, cy, XPixels.width(), lineHeight );
                 }
@@ -838,7 +846,7 @@ void ByteArrayRowViewPrivate::updateChanged()
                     columnIt.toFront();
                     while( columnIt.hasNext() )
                     {
-                        const KPixelXs XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( fullPositions );
+                        const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( fullPositions );
 
                         q->viewport()->update( XPixels.start()-xOffset, cy, XPixels.width(), lineHeight );
                     }
@@ -846,10 +854,10 @@ void ByteArrayRowViewPrivate::updateChanged()
                 // last line
                 cy += lineHeight;
                 columnIt.toFront();
-                const KHE::Section lastChangedPositions( fullPositions.start(), changedRange.end().pos() );
+                const LinePositionRange lastChangedPositions( fullPositions.start(), changedRange.end().pos() );
                 while( columnIt.hasNext() )
                 {
-                    const KPixelXs XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( lastChangedPositions );
+                    const PixelXRange XPixels = columnIt.next()->xsOfLinePositionsInclSpaces( lastChangedPositions );
 
                     q->viewport()->update( XPixels.start()-xOffset, cy, XPixels.width(), lineHeight );
                 }
@@ -866,34 +874,34 @@ void ByteArrayRowViewPrivate::updateChanged()
 }
 
 
-
 void ByteArrayRowViewPrivate::ensureCursorVisible()
 {
-//   // Not visible or the user is dragging the window, so don't position to caret yet
-//   if ( !isVisible() || isHorizontalSliderPressed() || isVerticalSliderPressed() )
-//   {
-//     d->ensureCursorVisibleInShowEvent = true;
-//     return;
-//   }
-  //static const int Margin = 10;
     ensureVisible( *mByteArrayColumn, mTableCursor->coord() );
 }
 
+void ByteArrayRowViewPrivate::ensureVisible( const AddressRange& range, bool ensureStartVisible )
+{
+    const CoordRange coords = mTableLayout->coordRangeOfIndizes( range );
+
+    // TODO: this is a make-it-work-hack, better do a smart calculation
+    ensureVisible( *mByteArrayColumn, ensureStartVisible ? coords.end() : coords.start() );
+    ensureVisible( *mByteArrayColumn, ensureStartVisible ? coords.start() : coords.end() );
+}
+
 void ByteArrayRowViewPrivate::ensureVisible( const ByteArrayRowColumnRenderer& column, const Coord& coord )
 {
     Q_Q( ByteArrayRowView );
 
-    // TODO: add getCursorRect to BufferColumn
-    const KPixelXs cursorXs = KPixelXs::fromWidth( column.xOfLinePosition(coord.pos()),
-                                                   column.byteWidth() );
+    const QRect byteRect = column.byteRect( coord );
 
-    const KPixelYs cursorYs = KPixelYs::fromWidth( q->lineHeight()*coord.line(), q->lineHeight() );
+    const PixelXRange byteXs = PixelXRange::fromWidth( byteRect.x(), byteRect.width() );
+    const PixelYRange byteYs = PixelYRange::fromWidth( byteRect.y(), byteRect.height() );
 
-    const KPixelXs visibleXs = KPixelXs::fromWidth( q->xOffset(), q->visibleWidth() );
-    const KPixelYs visibleYs = KPixelXs::fromWidth( q->yOffset(), q->visibleHeight() );
+    const PixelXRange visibleXs = PixelXRange::fromWidth( q->xOffset(), q->visibleWidth() );
+    const PixelYRange visibleYs = PixelXRange::fromWidth( q->yOffset(), q->visibleHeight() );
 
-    q->horizontalScrollBar()->setValue( visibleXs.startForInclude(cursorXs) );
-    q->verticalScrollBar()->setValue( visibleYs.startForInclude(cursorYs) );
+    q->horizontalScrollBar()->setValue( visibleXs.startForInclude(byteXs) );
+    q->verticalScrollBar()->setValue( visibleYs.startForInclude(byteYs) );
 }
 
 
@@ -912,6 +920,8 @@ void ByteArrayRowViewPrivate::mousePressEvent( QMouseEvent* mouseEvent )
 {
     Q_Q( ByteArrayRowView );
 
+    const bool oldHasSelection = mTableRanges->hasSelection();
+
     pauseCursor();
     mValueEditor->finishEdit();
 
@@ -925,7 +935,7 @@ void ByteArrayRowViewPrivate::mousePressEvent( QMouseEvent* mouseEvent )
             && (mouseEvent->globalPos()-mDoubleClickPoint).manhattanLength() < QApplication::startDragDistance() )
         {
             mTrippleClickTimer->stop();
-            const int indexAtFirstDoubleClickLinePosition = mTableLayout->indexAtFirstLinePosition( mDoubleClickLine );
+            const Address indexAtFirstDoubleClickLinePosition = mTableLayout->indexAtFirstLinePosition( mDoubleClickLine );
             mTableRanges->setSelectionStart( indexAtFirstDoubleClickLinePosition );
             mTableCursor->gotoIndex( indexAtFirstDoubleClickLinePosition );
             mTableCursor->gotoLineEnd();
@@ -933,7 +943,16 @@ void ByteArrayRowViewPrivate::mousePressEvent( QMouseEvent* mouseEvent )
             updateChanged();
 
             unpauseCursor();
+
+            const bool newHasSelection = mTableRanges->hasSelection();
             emit q->cursorPositionChanged( cursorPosition() );
+            emit q->selectionChanged( mTableRanges->selection() );
+            if( oldHasSelection != newHasSelection )
+            {
+                if( !mOverWrite ) emit q->cutAvailable( newHasSelection );
+                emit q->copyAvailable( newHasSelection );
+                emit q->hasSelectedDataChanged( newHasSelection );
+            }
             return;
         }
 
@@ -951,7 +970,7 @@ void ByteArrayRowViewPrivate::mousePressEvent( QMouseEvent* mouseEvent )
             placeCursor( mousePoint );
             ensureCursorVisible();
 
-            const int realIndex = mTableCursor->realIndex();
+            const Address realIndex = mTableCursor->realIndex();
             if( mTableRanges->selectionStarted() )
             {
                 if( mouseEvent->modifiers() & Qt::SHIFT )
@@ -983,6 +1002,15 @@ void ByteArrayRowViewPrivate::mousePressEvent( QMouseEvent* mouseEvent )
     }
 
     unpauseCursor();
+
+    const bool newHasSelection = mTableRanges->hasSelection();
+    emit q->selectionChanged( mTableRanges->selection() );
+    if( oldHasSelection != newHasSelection )
+    {
+        if( !mOverWrite ) emit q->cutAvailable( newHasSelection );
+        emit q->copyAvailable( newHasSelection );
+        emit q->hasSelectedDataChanged( newHasSelection );
+    }
 }
 
 
@@ -1021,6 +1049,7 @@ void ByteArrayRowViewPrivate::mouseReleaseEvent( QMouseEvent* mouseEvent )
 {
     Q_Q( ByteArrayRowView );
 
+    const bool oldHasSelection = mTableRanges->hasSelection();
     const QPoint releasePoint = q->viewportToColumns( mouseEvent->pos() );
 
     // this is not the release of a doubleclick so we need to process it?
@@ -1028,7 +1057,7 @@ void ByteArrayRowViewPrivate::mouseReleaseEvent( QMouseEvent* mouseEvent )
     {
         const int line = q->lineAt( releasePoint.y() );
         const int pos = mByteArrayColumn->linePositionOfX( releasePoint.x() ); // TODO: can we be sure here about the active column?
-        const int index = mTableLayout->indexAtCCoord( Coord(pos,line) ); // TODO: can this be another index than the one of the cursor???
+        const Address index = mTableLayout->indexAtCCoord( Coord(pos,line) ); // TODO: can this be another index than the one of the cursor???
         emit q->clicked( index );
     }
 
@@ -1098,10 +1127,14 @@ void ByteArrayRowViewPrivate::mouseReleaseEvent( QMouseEvent* mouseEvent )
     if( mTableRanges->selectionJustStarted() )
         mTableRanges->removeSelection();
 
-    if( !mOverWrite ) emit q->cutAvailable( mTableRanges->hasSelection() );
-    emit q->copyAvailable( mTableRanges->hasSelection() );
-    emit q->selectionChanged( mTableRanges->hasSelection() );
+    const bool newHasSelection = mTableRanges->hasSelection();
     emit q->selectionChanged( mTableRanges->selection() );
+    if( oldHasSelection != newHasSelection )
+    {
+        if( !mOverWrite ) emit q->cutAvailable( newHasSelection );
+        emit q->copyAvailable( newHasSelection );
+        emit q->hasSelectedDataChanged( newHasSelection );
+    }
 }
 
 
@@ -1119,7 +1152,7 @@ void ByteArrayRowViewPrivate::mouseDoubleClickEvent( QMouseEvent* mouseEvent )
 
     mDoubleClickLine = mTableCursor->line();
 
-    const int index = mTableCursor->validIndex();
+    const Address index = mTableCursor->validIndex();
 
     if( mActiveCoding == AbstractByteArrayView::CharCodingId )
     {
@@ -1152,6 +1185,7 @@ void ByteArrayRowViewPrivate::handleMouseMove( const QPoint& point ) // handles
 {
     Q_Q( ByteArrayRowView );
 
+    const bool oldHasSelection = mTableRanges->hasSelection();
     const int yOffset = q->yOffset();
     const int behindLastYOffset = yOffset + q->visibleHeight();
     // scrolltimer but inside of viewport?
@@ -1174,9 +1208,9 @@ void ByteArrayRowViewPrivate::handleMouseMove( const QPoint& point ) // handles
     // do wordwise selection?
     if( mInDoubleClick && mTableRanges->hasFirstWordSelection() )
     {
-        int newIndex = mTableCursor->realIndex();
-        const KHE::Section firstWordSelection = mTableRanges->firstWordSelection();
-        const KHECore::WordByteArrayService WBS( mByteArrayModel, charCodec() );
+        Address newIndex = mTableCursor->realIndex();
+        const AddressRange firstWordSelection = mTableRanges->firstWordSelection();
+        const WordByteArrayService WBS( mByteArrayModel, charCodec() );
         // are we before the selection?
         if( firstWordSelection.startsBehind(newIndex) )
         {
@@ -1205,9 +1239,16 @@ void ByteArrayRowViewPrivate::handleMouseMove( const QPoint& point ) // handles
     updateChanged();
 
     unpauseCursor();
+
+    const bool newHasSelection = mTableRanges->hasSelection();
     emit q->cursorPositionChanged( cursorPosition() );
-    emit q->selectionChanged( mTableRanges->hasSelection() );
     emit q->selectionChanged( mTableRanges->selection() );
+    if( oldHasSelection != newHasSelection )
+    {
+        if( !mOverWrite ) emit q->cutAvailable( newHasSelection );
+        emit q->copyAvailable( newHasSelection );
+        emit q->hasSelectedDataChanged( newHasSelection );
+    }
 }
 
 
@@ -1232,14 +1273,19 @@ void ByteArrayRowViewPrivate::startDrag()
     Qt::DropAction dropAction = drag->exec( request );
 
     if( dropAction == Qt::MoveAction )
+    {
+        AbstractByteArrayView* targetByteArrayView = qobject_cast<AbstractByteArrayView*>( drag->target() );
         // Not inside this widget itself?
-        if( drag->target() != q )
+        if( ! targetByteArrayView
+            || targetByteArrayView->byteArrayModel() != q->byteArrayModel() )
             removeSelectedData();
+    }
 }
 
 ByteArrayRowViewPrivate::~ByteArrayRowViewPrivate()
 {
     delete mCursorPixmaps;
+    delete mStylist;
 }
 
 }
