@@ -20,26 +20,25 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef KHE_UI_CHARBYTEARRAYCOLUMNRENDERER_H
-#define KHE_UI_CHARBYTEARRAYCOLUMNRENDERER_H
-
+#ifndef OKTETA_CHARBYTEARRAYCOLUMNRENDERER_H
+#define OKTETA_CHARBYTEARRAYCOLUMNRENDERER_H
 
 // lib
 #include "abstractbytearraycolumnrenderer.h"
 
 
-namespace KHEUI
+namespace Okteta
 {
 
 /** buffer column that interprets the bytes as chars
   *
   *@author Friedrich W. H. Kossebau
   */
-class CharByteArrayColumnRenderer : public AbstractByteArrayColumnRenderer
+class OKTETAGUI_EXPORT CharByteArrayColumnRenderer : public AbstractByteArrayColumnRenderer
 {
   public:
-    CharByteArrayColumnRenderer( ColumnsView *columnsView,
-        KHECore::AbstractByteArrayModel* byteArrayModel, ByteArrayTableLayout* layout, ByteArrayTableRanges* ranges );
+    CharByteArrayColumnRenderer( AbstractColumnStylist* stylist,
+        AbstractByteArrayModel* byteArrayModel, ByteArrayTableLayout* layout, ByteArrayTableRanges* ranges );
     virtual ~CharByteArrayColumnRenderer();
 
 
@@ -72,7 +71,7 @@ class CharByteArrayColumnRenderer : public AbstractByteArrayColumnRenderer
 
 
   protected: // AbstractByteArrayColumnRenderer API
-    virtual void renderByteText( QPainter *painter, char byte, KHECore::KChar byteChar, const QColor &color ) const;
+    virtual void renderByteText( QPainter *painter, Byte byte, Character byteChar, const QColor& color ) const;
 
   protected:
     /** */
