@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Gui library, part of the KDE project.
 
-    Copyright 2003 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2003,2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -20,23 +20,23 @@
     License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#ifndef KHE_UI_KADDS_H
-#define KHE_UI_KADDS_H
+#ifndef OKTETA_KADDS_H
+#define OKTETA_KADDS_H
 
-namespace KHE {
-class Section;
-}
+// Okteta core
+#include <numberrange.h>
 
-namespace KHEUI
+namespace Okteta
 {
 // some possibly useful additions to KDE
 
 // these are to emphasize that measuring unit is pixel and which direction
-typedef int KPixelX;
-typedef int KPixelY;
+typedef int PixelX;
+typedef int PixelY;
+
+typedef KDE::NumberRange<PixelX> PixelXRange;
+typedef KDE::NumberRange<PixelY> PixelYRange;
 
-typedef KHE::Section KPixelXs;
-typedef KHE::Section KPixelYs;
 }
 
 #endif
