@@ -26,7 +26,8 @@
 // Qt
 #include <QtCore/QObject>
 
-namespace KHEUI
+
+namespace Okteta
 {
 
 class ByteArrayTableLayoutTest : public QObject
@@ -38,6 +39,7 @@ class ByteArrayTableLayoutTest : public QObject
     void testSetStartOffset();
     void testSetFirstLineOffset();
     void testSetNoOfBytesPerLine();
+    void testSetByteArrayOffset();
     void testSetLength();
     void testSetNoOfLinesPerPage();
 };
