@@ -26,6 +26,10 @@
 // Qt
 #include <QtCore/QObject>
 
+
+namespace Okteta
+{
+
 class CoordRangeListTest : public QObject
 {
   Q_OBJECT
@@ -37,4 +41,6 @@ class CoordRangeListTest : public QObject
     void testAddNonJoinableSections();
 };
 
+}
+
 #endif
