@@ -8,7 +8,7 @@
     published by the Free Software Foundation; either version 2 of
     the License or (at your option) version 3 or any later version
     accepted by the membership of KDE e.V. (or its successor approved
-    by the membership of KDE e.V.), which shall act as a proxy 
+    by the membership of KDE e.V.), which shall act as a proxy
     defined in Section 14 of version 3 of the license.
 
     This program is distributed in the hope that it will be useful,
@@ -25,15 +25,14 @@
 // KDE
 #include <KLocale>
 
-#include <kdeversion.h>
-
 
 // Program
 static const char ProgramId[] =          "okteta";
-static const char ProgramVersion[] =     "0.3.1";
+static const char ProgramVersion[] =     "0.4.0";
 static const char ProgramHomepage[] =    "http://utils.kde.org/projects/okteta";
 // Author
 static const char FWHKEmailAddress[] =   "kossebau@kde.org";
+static const char AREmailAddress[] =     "alex.richardson@gmx.de";
 
 
 OktetaAboutData::OktetaAboutData()
@@ -41,7 +40,7 @@ OktetaAboutData::OktetaAboutData()
               ki18n("Okteta"), ProgramVersion, // name
               ki18n("KDE byte editor"), // description
               KAboutData::License_GPL_V2,
-              ki18n("Copyright 2006-2009 Friedrich W. H. Kossebau"), //copyright
+              ki18n("Copyright 2006-2010 Friedrich W. H. Kossebau"), //copyright
               ki18n("Edit the raw data of files"), // comment
               ProgramHomepage )
 {
@@ -50,4 +49,7 @@ OktetaAboutData::OktetaAboutData()
     addAuthor( ki18n("Friedrich W. H. Kossebau"), // name
                ki18n("Author"), // task
                FWHKEmailAddress );
+    addAuthor( ki18nc("Author","Alexander Richardson"),// name
+               ki18nc("Task description","Structures tool"), // task
+               AREmailAddress );
 }
